@@ -88,12 +88,20 @@ void MainWindow::readdirs()
 void MainWindow::writeSettings()
 {
     QSettings sett("ThemeCustomizer", "Boxes");
-    sett.setValue("icons", ui->Icons->currentIndex());
+//    sett.setValue("icons", ui->Icons->currentIndex());
     sett.setValue("snap", ui->Snap->text());
     sett.setValue("fontsize", ui->FontSize->currentIndex());
     sett.setValue("iconset", ui->Iconset->currentIndex());
     sett.setValue("appsize", ui->lineEdit->text());
     sett.setValue("booksize", ui->lineEdit_2->text());
+
+    QString Icons;
+    if ( ui->Icons->checkState() == Qt::Checked ) {
+        sett.setValue("icons", "1");
+    }
+    else {
+        sett.setValue("icons", "0");
+    }
 }
 
 void MainWindow::readSettings()
@@ -108,8 +116,15 @@ void MainWindow::readSettings()
     QString appsizestring = sett.value("appsize").toString();
     QString booksizestring = sett.value("booksize").toString();
     QString snapstring = sett.value("snap").toString();
-    ui->Icons->setCurrentIndex(icons);
+    // ui->Icons->setCurrentIndex(icons);
     // ui->Snap->setCurrentIndex(snap);
+
+    if ( icons == 1 ) {
+        ui->Icons->setCheckState(Qt::Checked);
+    } else {
+        ui->Icons->setCheckState(Qt::Unchecked);
+    }
+
     ui->FontSize->setCurrentIndex(fontsize);
     ui->Iconset->setCurrentIndex(iconset);
 
@@ -138,6 +153,15 @@ void MainWindow::on_pushButton_clicked()
         else {
             checkboxstate = "0";
         }
+
+        QString Icons;
+        if ( ui->Icons->checkState() == Qt::Checked ) {
+            Icons = "Show icons";
+        }
+        else {
+            Icons = "Don't show icon backgrounds";
+        }
+
         writeSettings();
         QString varattu;
         varattu = "Theme Customizer";
@@ -145,7 +169,7 @@ void MainWindow::on_pushButton_clicked()
         progress.setWindowTitle(varattu);
         progress.setCancelButton(0);
         QStringList arguments;
-        arguments << ui->FontSize->currentText() << ui->Fonter->currentText() << ui->Iconset->currentText() << ui->Icons->currentText() << ui->lineEdit->text() << ui->Snap->text() << checkboxstate << fonts << ui->font1->text() << ui->font2->text() << ui->font3->text() << ui->font4->text() << ui->lineEdit_2->text() << ui->font5->text() << ui->font6->text();
+        arguments << ui->FontSize->currentText() << ui->Fonter->currentText() << ui->Iconset->currentText() << Icons << ui->lineEdit->text() << ui->Snap->text() << checkboxstate << fonts << ui->font1->text() << ui->font2->text() << ui->font3->text() << ui->font4->text() << ui->lineEdit_2->text() << ui->font5->text() << ui->font6->text();
         QProcess *process = new QProcess(this);
         connect(process, SIGNAL(finished(int)), this, SLOT(processFinished(int)));
         process->start("/sbin/launchcustomizer", arguments);
@@ -362,3 +386,15 @@ void MainWindow::process2Finished(int)
 {
     progress2.cancel();
 }
+
+void MainWindow::on_about_triggered()
+{
+    QMessageBox msgBox;
+    msgBox.setWindowTitle("About Theme Customizer");
+    msgBox.setText("Author: D-Iivil - Licence: Freeware & open source");
+    msgBox.setTextFormat(Qt::RichText);
+    msgBox.setInformativeText("<html><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Donate some beer money to author</a></html>");
+    msgBox.setStandardButtons(QMessageBox::Ok);
+    msgBox.setDefaultButton(QMessageBox::Ok);
+    msgBox.exec();
+}
